project_files/HedgewarsMobile/Classes/GameSetup.m
changeset 4924 616b618814b5
parent 4861 91f889289a47
child 4976 088d40d8aba2
--- a/project_files/HedgewarsMobile/Classes/GameSetup.m	Sat Feb 05 23:37:25 2011 +0300
+++ b/project_files/HedgewarsMobile/Classes/GameSetup.m	Sat Feb 05 22:22:16 2011 +0100
@@ -394,8 +394,10 @@
                 }
                 break;
             case 'q':
                 // game ended, can remove the savefile
                 [[NSFileManager defaultManager] removeItemAtPath:self.savePath error:nil];
+                if (IS_DUALHEAD())
+                    [[NSNotificationCenter defaultCenter] postNotificationName:@"remove overlay" object:nil];
                 break;
             case 'Q':
                 // game exited but not completed, nothing to do (just don't save the message)
@@ -394,8 +394,10 @@
                 break;
             case 'q':
-                // game ended, can remove the savefile
+                // game ended, can remove the savefile and the trailing overlay (when dualhead)
                 [[NSFileManager defaultManager] removeItemAtPath:self.savePath error:nil];